.custom-table {
    border: 1px solid gray !important;
    box-shadow: 8px 8px 10px #888888;
}

.custom-table th {
    background-color: rgb(10, 131, 116);
}

.custom-table thead tr th.Id {
    display: none;
}

.custom-table tbody tr td.id {
    display: none;
}
