{% load static %}

<link href="{% static 'onepage/bootstrap/css/bootstrap.min.css' %}" rel="stylesheet">
<link href="{% static 'onepage/metisMenu/metisMenu.css' %}" rel="stylesheet">

<link href="{% static 'onepage/datatables/dataTables.min.css' %}" rel="stylesheet">
<link href="{% static 'onepage/datatables/dataTables.bootstrap4.min.css' %}" rel="stylesheet">
<link href="{% static 'onepage/datatables/responsive.bootstrap4.min.css' %}" rel="stylesheet">
<link href="{% static 'onepage/datatables/buttons.bootstrap4.min.css' %}" rel="stylesheet">
<link href="{% static 'onepage/modals/component.css'%}" rel="stylesheet">

<link href="{% static 'onepage/select2/dist/css/select2.min.css' %}" rel="stylesheet">
<link href="{% static 'onepage/select2-bootstrap4/dist/select2-bootstrap4.min.css' %}" rel="stylesheet">

<link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-tagsinput/0.8.0/bootstrap-tagsinput.css" rel="stylesheet"/>
<link href="https://cdnjs.cloudflare.com/ajax/libs/jquery-datetimepicker/2.5.20/jquery.datetimepicker.min.css" rel="stylesheet"/>
<link href="{% static 'onepage/sweetalert/sweetalert.css' %}" rel="stylesheet">

<link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Roboto:100,300,400,500&display=swap">
<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css"
      integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.7.2/css/all.css"
      integrity="sha384-fnmOCqbTlWIlj8LyTjo7mOUStjsKC4pOpQbqyi7RrhN7udi9RwhKkMHpvLbHG9Sr" crossorigin="anonymous">
<link rel="stylesheet" href="{% static 'onepage/assets/css/jquery.mCustomScrollbar.min.css' %}">
<link rel="stylesheet" href="{% static 'onepage/assets/css/animate.css' %}">
<link rel="stylesheet" href="{% static 'onepage/assets/css/style.css' %}">
<link rel="stylesheet" href="{% static 'onepage/assets/css/media-queries.css' %}">

<link href="{% static 'onepage/style.css' %}" rel="stylesheet">

{% include 'onepage/header-js.html' %}
